Struct NoChannelStore
Source pub struct NoChannelStore;
No-op channel store — use when channel persistence is not needed.
Upsert the channel record for name.
Remove the channel record for name. A no-op if not present.
Invoke
f for every persisted channel record.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.